summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--AUTHORS4
-rw-r--r--Makefile2
-rw-r--r--README.md11
-rw-r--r--common.mk6
-rw-r--r--local_settings.py.example2
-rw-r--r--main/fixtures/groups.json2
-rw-r--r--main/templatetags/wiki.py4
-rw-r--r--packages/templatetags/jinja2.py45
-rw-r--r--packages/utils.py6
-rw-r--r--packages/views/__init__.py5
-rw-r--r--packages/views/flag.py4
-rw-r--r--public/views.py43
-rw-r--r--settings.py39
-rw-r--r--sitestatic/Makefile5
-rw-r--r--sitestatic/archnavbar/Makefile8
-rw-r--r--sitestatic/archnavbar/archnavbar.css17
-rw-r--r--sitestatic/archweb.css39
-rw-r--r--sitestatic/freedomincluded.pngbin0 -> 3116 bytes
-rw-r--r--sitestatic/gnuchile.pngbin0 -> 7476 bytes
-rw-r--r--sitestatic/logos/Makefile15
-rw-r--r--sitestatic/naltu.pngbin0 -> 5270 bytes
-rw-r--r--sitestatic/venenux.pngbin0 -> 8714 bytes
-rw-r--r--templates/base.html23
-rw-r--r--templates/devel/clock.html10
-rw-r--r--templates/devel/index.html2
-rw-r--r--templates/packages/details.html.jinja5
-rw-r--r--templates/packages/differences.html29
-rw-r--r--templates/packages/flag.html4
-rw-r--r--templates/packages/flaghelp.html4
-rw-r--r--templates/packages/removed.html5
-rw-r--r--templates/packages/search.html12
-rw-r--r--templates/public/about.html105
-rw-r--r--templates/public/art.html114
-rw-r--r--templates/public/donate.html64
-rw-r--r--templates/public/download.html114
-rw-r--r--templates/public/feeds.html70
-rw-r--r--templates/public/https.html49
-rw-r--r--templates/public/index.html95
-rw-r--r--templates/public/svn.html41
-rw-r--r--urls.py21
40 files changed, 441 insertions, 583 deletions
diff --git a/AUTHORS b/AUTHORS
index 1bfaaf00..5ab816b3 100644
--- a/AUTHORS
+++ b/AUTHORS
@@ -8,3 +8,7 @@ eliott <eliott@cactuswax.net>
Thayer Williams <thayer@archlinux.org>
Dusty Phillips <dusty@archlinux.org>
+# PARABOLAWEB AUTHORS
+Konstantinos Karantias <kostis@gtklocker.com>
+Nicolás Reynolds <fauno@kiwwwi.com.ar>
+Luke Shumaker <lukeshu@sbcglobal.net>
diff --git a/Makefile b/Makefile
index 9c3fafea..6cc53cf5 100644
--- a/Makefile
+++ b/Makefile
@@ -1,4 +1,4 @@
-subdirs = sitestatic visualize/static
+subdirs = sitestatic sitestatic/archnavbar sitestatic/logos visualize/static
define newline =
diff --git a/README.md b/README.md
index 3e48ca8c..b2a45c47 100644
--- a/README.md
+++ b/README.md
@@ -1,3 +1,14 @@
+# Parabolaweb README
+It is recommended that you just install the (parabola) package
+`parabolaweb-utils`, it
+
+ - depends on the dependencies of parabolaweb
+ - offers initscripts and systemd service files for parabolaweb
+ - has a `parabolaweb-update` script that does most of the things here.
+
+Following is Archweb's readme, as I figure it might be useful for some people,
+but I have given up on maintaining it for parabolaweb.
+
# Archweb README
To get a pretty version of this document, run
diff --git a/common.mk b/common.mk
index a0db5d70..35f0b3bb 100644
--- a/common.mk
+++ b/common.mk
@@ -1,5 +1,7 @@
topdir := $(dir $(lastword $(MAKEFILE_LIST)))
www = $(topdir)/../web-cache/www
+artwork = $(topdir)/../web-cache/artwork
+branding = $(artwork)/official-2013/optimized-text
#JSMIN = cp $1 $2
#JSMIN = compiler $1
@@ -19,4 +21,8 @@ $(www)/https/%:
wget 'http://$*' -O '$@'
touch '$@'
+$(branding)/%:
+ gitget checkout 'git://projects.parabolagnulinux.org/artwork.git#branch=master' '$(artwork)'
+ make -C '$(branding)'
+
.PHONY: PHONY
diff --git a/local_settings.py.example b/local_settings.py.example
index 52eab33c..3e33aa7e 100644
--- a/local_settings.py.example
+++ b/local_settings.py.example
@@ -1,4 +1,4 @@
-### Django settings for archlinux project.
+### Django settings for Parabola GNU/Linux-libre project.
## Debug settings
DEBUG = False # If you are running without another HTTP server, must be true
diff --git a/main/fixtures/groups.json b/main/fixtures/groups.json
index 134b98b3..c309095e 100644
--- a/main/fixtures/groups.json
+++ b/main/fixtures/groups.json
@@ -3,7 +3,7 @@
"pk": 1,
"model": "auth.group",
"fields": {
- "name": "Developers",
+ "name": "Hackers",
"permissions": [
[
"change_package",
diff --git a/main/templatetags/wiki.py b/main/templatetags/wiki.py
index b1b8dd55..4a3b2f83 100644
--- a/main/templatetags/wiki.py
+++ b/main/templatetags/wiki.py
@@ -4,6 +4,6 @@ register = template.Library()
@register.simple_tag
def wiki_url(article=""):
if article == "":
- return "https://wiki.archlinux.org/"
+ return "https://wiki.parabolagnulinux.org/"
else:
- return "https://wiki.archlinux.org/index.php/"+article.replace(' ', '_')
+ return "https://wiki.parabolagnulinux.org/"+article.replace(' ', '_')
diff --git a/packages/templatetags/jinja2.py b/packages/templatetags/jinja2.py
index 22f9914b..c9d602a6 100644
--- a/packages/templatetags/jinja2.py
+++ b/packages/templatetags/jinja2.py
@@ -31,40 +31,59 @@ def pgp_key_link(key_id, link_text=None):
@library.global_function
def scm_link(package, operation):
- parts = (package.repo.svn_root, operation, package.pkgbase)
+ parts = ("abslibre", operation, package.repo.name.lower(), package.pkgbase)
linkbase = (
- "https://projects.archlinux.org/svntogit/%s.git/%s/trunk?"
- "h=packages/%s")
+ "https://projects.parabolagnulinux.org/%s.git/%s/%s/%s")
return linkbase % tuple(urlquote(part.encode('utf-8')) for part in parts)
@library.global_function
def wiki_link(package):
- url = "https://wiki.archlinux.org/index.php/Special:Search"
+ url = "https://wiki.parabolagnulinux.org/index.php"
data = {
+ 'title': "Special:Search",
'search': package.pkgname,
}
return link_encode(url, data)
-
@library.global_function
def bugs_list(package):
- url = "https://bugs.archlinux.org/"
+ url = "https://labs.parabola.nu/search/index/"
+ if package.arch.name == 'mips64el':
+ url = url + "mips64el"
+ else:
+ url = url + "issue-tracker"
data = {
- 'project': package.repo.bugs_project,
- 'cat[]': package.repo.bugs_category,
- 'string': package.pkgname,
+ 'titles_only': '1',
+ 'issues': '1',
+ 'q': package.pkgname,
}
return link_encode(url, data)
@library.global_function
def bug_report(package):
- url = "https://bugs.archlinux.org/newtask"
+ url = "https://labs.parabola.nu/projects/"
+ if package.arch.name == 'mips64el':
+ url = url + "mips64el/issues/new"
+ else:
+ url = url + "issue-tracker/issues/new"
+ data = {
+ 'issue[subject]': '[%s] PLEASE ENTER SUMMARY' % package.pkgname,
+ }
+ return link_encode(url, data)
+
+@library.global_function
+def flag_unfree(package):
+ url = "https://labs.parabola.nu/projects/"
+ if package.arch.name == 'mips64el':
+ url = url + "mips64el/issues/new"
+ else:
+ url = url + "issue-tracker/issues/new"
data = {
- 'project': package.repo.bugs_project,
- 'product_category': package.repo.bugs_category,
- 'item_summary': '[%s] PLEASE ENTER SUMMARY' % package.pkgname,
+ 'issue[priority_id]': '1', # "freedom issue"
+ 'issue[watcher_user_ids][]': '62', # "dev-list"
+ 'issue[subject]': '[%s] Please put your reasons here (register first if you haven\'t)' % package.pkgname,
}
return link_encode(url, data)
diff --git a/packages/utils.py b/packages/utils.py
index 0f47f170..c38aa840 100644
--- a/packages/utils.py
+++ b/packages/utils.py
@@ -137,6 +137,10 @@ SELECT p.id, q.id
)
WHERE p.arch_id IN (%s, %s)
AND (
+ q.arch_id IN (%s, %s)
+ OR q.id IS NULL
+ )
+ AND (
q.id IS NULL
OR p.pkgver != q.pkgver
OR p.pkgrel != q.pkgrel
@@ -144,7 +148,7 @@ SELECT p.id, q.id
)
"""
cursor = connection.cursor()
- cursor.execute(sql, [arch_a.id, arch_b.id])
+ cursor.execute(sql, [arch_a.id, arch_b.id, arch_a.id, arch_b.id])
results = cursor.fetchall()
# column A will always have a value, column B might be NULL
to_fetch = {row[0] for row in results}
diff --git a/packages/views/__init__.py b/packages/views/__init__.py
index 46c99985..1f8a0169 100644
--- a/packages/views/__init__.py
+++ b/packages/views/__init__.py
@@ -107,14 +107,15 @@ def update(request):
def arch_differences(request):
# TODO: we have some hardcoded magic here with respect to the arches.
- arch_a = Arch.objects.get(name='i686')
- arch_b = Arch.objects.get(name='x86_64')
+ arch_a = Arch.objects.get(name=request.GET.get('arch_a', 'i686'))
+ arch_b = Arch.objects.get(name=request.GET.get('arch_b', 'x86_64'))
differences = get_differences_info(arch_a, arch_b)
multilib_diffs = multilib_differences()
context = {
'arch_a': arch_a,
'arch_b': arch_b,
'differences': differences,
+ 'arches': Arch.objects.filter(agnostic=False),
'multilib_differences': multilib_diffs
}
return render(request, 'packages/differences.html', context)
diff --git a/packages/views/flag.py b/packages/views/flag.py
index 5680683a..c6936ac4 100644
--- a/packages/views/flag.py
+++ b/packages/views/flag.py
@@ -5,6 +5,7 @@ from django.conf import settings
from django.contrib.auth.decorators import permission_required
from django.core.mail import EmailMessage
from django.db import transaction
+from django.db.models import Q
from django.shortcuts import get_object_or_404, redirect, render
from django.template import loader, Context
from django.utils.timezone import now
@@ -58,7 +59,8 @@ def flag(request, name, repo, arch):
pkgs = Package.objects.normal().filter(
pkgbase=pkg.pkgbase, flag_date__isnull=True,
repo__testing=pkg.repo.testing,
- repo__staging=pkg.repo.staging).order_by(
+ repo__staging=pkg.repo.staging).filter(
+ Q(arch__name='mips64el') | Q(repo__name='Libre') | Q(repo__name='Pcr')).order_by(
'pkgname', 'repo__name', 'arch__name')
authenticated = request.user.is_authenticated()
diff --git a/public/views.py b/public/views.py
index d1661afd..f04f357b 100644
--- a/public/views.py
+++ b/public/views.py
@@ -5,7 +5,7 @@ from operator import attrgetter
from django.conf import settings
from django.contrib.auth.models import User
from django.db.models import Count, Q
-from django.http import Http404, HttpResponse
+from django.http import Http404, HttpResponse, HttpResponseRedirect
from django.shortcuts import render
from django.views.decorators.cache import cache_control, cache_page
@@ -32,35 +32,28 @@ def index(request):
return render(request, 'public/index.html', context)
USER_LISTS = {
- 'devs': {
- 'user_type': 'Developers',
- 'user_title': 'Developer',
- 'description': "This is a list of the current "+settings.BRANDING_DISTRONAME+" Developers. They maintain the [core] and [extra] package repositories in addition to doing any other developer duties.",
- },
- 'tus': {
- 'user_type': 'Trusted Users',
- 'user_title': 'Trusted User',
- 'description': "Here are all your friendly "+settings.BRANDING_DISTRONAME+" Trusted Users who are in charge of the [community] repository.",
+ 'hackers': {
+ 'user_type': 'Hackers',
+ 'user_title': 'Hacker',
+ 'description': "This is a list of the current "+settings.BRANDING_SHORTNAME+" Hackers. They maintain the [libre] package repository and keep the [core], [extra] and [community] repositories clean of unfree software, in addition to doing any other developer duties.",
},
'fellows': {
'user_type': 'Fellows',
'user_title': 'Fellow',
- 'description': "Below you can find a list of ex-developers (aka project fellows). These folks helped make "+settings.BRANDING_SHORTNAME+" what it is today. Thanks!",
+ 'description': "Below you can find a list of ex-hackers (aka project fellows). These folks helped make "+settings.BRANDING_SHORTNAME+" what it is today. Thanks!",
},
}
@cache_control(max_age=300)
-def userlist(request, user_type='devs'):
+def userlist(request, user_type='hackers'):
users = User.objects.order_by(
- 'first_name', 'last_name').select_related('userprofile')
- if user_type == 'devs':
- users = users.filter(is_active=True, groups__name="Developers")
- elif user_type == 'tus':
- users = users.filter(is_active=True, groups__name="Trusted Users")
+ 'username').select_related('userprofile')
+ if user_type == 'hackers':
+ users = users.filter(is_active=True, groups__name="Hackers")
elif user_type == 'fellows':
users = users.filter(is_active=False,
- groups__name__in=["Developers", "Trusted Users"])
+ groups__name__in=["Hackers"])
else:
raise Http404
@@ -90,19 +83,7 @@ def _mirror_urls():
@cache_control(max_age=300)
def download(request):
- try:
- release = Release.objects.filter(available=True).latest()
- except Release.DoesNotExist:
- release = None
-
- context = {
- 'release': release,
- 'releng_iso_url': settings.ISO_LIST_URL,
- 'releng_pxeboot_url': settings.PXEBOOT_URL,
- 'mirror_urls': _mirror_urls,
- }
- return render(request, 'public/download.html', context)
-
+ return HttpResponseRedirect('https://wiki.parabolagnulinux.org/get')
@cache_control(max_age=300)
def feeds(request):
diff --git a/sitestatic/Makefile b/sitestatic/Makefile
index e99e3c96..d716992f 100644
--- a/sitestatic/Makefile
+++ b/sitestatic/Makefile
@@ -9,7 +9,7 @@ targets = \
jquery.tablesorter-$(tablesorter-ver) \
konami
-target-files=$(addsuffix .js,$(targets)) $(addsuffix .min.js,$(targets))
+target-files=$(addsuffix .js,$(targets)) $(addsuffix .min.js,$(targets)) favicon.ico silhouette.png
all: $(target-files)
clean:
rm -f -- $(target-files)
@@ -22,3 +22,6 @@ jquery.tablesorter-$(tablesorter-ver).js: $(www)/https/raw.github.com/Mottie/tab
cp $< $@
konami.js: %: $(www)/https/raw.github.com/snaptortoise/konami-js/master/%
cp $< $@
+
+favicon.ico silhouette.png: %: $(branding)/%
+ cp $< $@
diff --git a/sitestatic/archnavbar/Makefile b/sitestatic/archnavbar/Makefile
new file mode 100644
index 00000000..a4b5e777
--- /dev/null
+++ b/sitestatic/archnavbar/Makefile
@@ -0,0 +1,8 @@
+include ../../common.mk
+
+all: archlogo.png
+clean:
+ rm -f archlogo.png
+
+archlogo.png: %: $(branding)/%
+ cp $< $@
diff --git a/sitestatic/archnavbar/archnavbar.css b/sitestatic/archnavbar/archnavbar.css
index d10c5f52..4fcd6cc6 100644
--- a/sitestatic/archnavbar/archnavbar.css
+++ b/sitestatic/archnavbar/archnavbar.css
@@ -5,21 +5,30 @@
*/
/* container for the entire bar */
-#archnavbar { height: 40px !important; padding: 10px 15px !important; background: #333 !important; border-bottom: 5px #08c solid !important; }
-#archnavbarlogo { background: url('archlogo.png') no-repeat !important; }
+#archnavbar { height: 40px !important; padding: 10px 15px !important; background: #000 !important; border-bottom: 5px #787DAB solid !important; }
+#archnavbarlogo { float: left !important; margin: -5px 0 0 0 !important; padding: 0 !important; height: 50px !important; width: 324px !important; background: url('archlogo.png') no-repeat !important; }
/* move the heading/paragraph text offscreen */
#archnavbarlogo p { margin: 0 !important; padding: 0 !important; text-indent: -9999px !important; }
#archnavbarlogo h1 { margin: 0 !important; padding: 0 !important; text-indent: -9999px !important; }
/* make the link the same size as the logo */
-#archnavbarlogo a { display: block !important; height: 40px !important; width: 190px !important; }
+#archnavbarlogo a { display: block !important; height: 50px !important; width: 324px !important; }
/* display the list inline, float it to the right and style it */
#archnavbar ul { display: inline !important; float: right !important; list-style: none !important; margin: 0 !important; padding: 0 !important; }
#archnavbar ul li { float: left !important; font-size: 14px !important; font-family: sans-serif !important; line-height: 45px !important; padding-right: 15px !important; padding-left: 15px !important; }
/* style the links */
-#archnavbar ul#archnavbarlist li a { color: #999; font-weight: bold !important; text-decoration: none !important; }
+#archnavbar ul li a { color: #999; font-weight: bold !important; text-decoration: none !important; }
#archnavbar ul li a:hover { color: white !important; text-decoration: underline !important; }
+/* END MAIN NAVBAR STYLES */
+
+/* highlight current website in the navbar */
+li.anb-selected a,
+#archnavbar.anb-home ul li#anb-home a,
+#archnavbar.anb-packages ul li#anb-packages a,
+#archnavbar.anb-download ul li#anb-download a {
+ color: white !important;
+}
diff --git a/sitestatic/archweb.css b/sitestatic/archweb.css
index edabcfb7..0a16687e 100644
--- a/sitestatic/archweb.css
+++ b/sitestatic/archweb.css
@@ -6,31 +6,7 @@
* 11px = 0.6875em
*/
-/*
- * ARCH GLOBAL NAVBAR
- * We're forcing all generic selectors with !important
- * to help prevent other stylesheets from interfering.
- */
-
-/* container for the entire bar */
-#archnavbar { height: 40px !important; padding: 10px 15px !important; background: #333 !important; border-bottom: 5px #08c solid !important; }
-#archnavbarlogo { float: left !important; margin: 0 !important; padding: 0 !important; height: 40px !important; width: 190px !important; background: url('archnavbar/archlogo.png') no-repeat !important; }
-
-/* move the heading text offscreen */
-#archnavbarlogo h1 { margin: 0 !important; padding: 0 !important; text-indent: -9999px !important; }
-
-/* make the link the same size as the logo */
-#archnavbarlogo a { display: block !important; height: 40px !important; width: 190px !important; }
-
-/* display the list inline, float it to the right and style it */
-#archnavbarlist { display: inline !important; float: right !important; list-style: none !important; margin: 0 !important; padding: 0 !important; }
-#archnavbarlist li { float: left !important; font-size: 14px !important; font-family: sans-serif !important; line-height: 45px !important; padding-right: 15px !important; padding-left: 15px !important; }
-
-/* style the links */
-#archnavbarlist li a { color: #999; font-weight: bold !important; text-decoration: none !important; }
-#archnavbarlist li a:hover { color: white !important; text-decoration: underline !important; }
-
-/* END ARCH GLOBAL NAVBAR */
+@import url("archnavbar/archnavbar.css");
/* simple reset */
* {
@@ -479,7 +455,7 @@ table thead th.sorter-false {
/* home: arrowed headings */
#news h3 a {
display: block;
- background: #1794D1;
+ background: #787DAB;
font-size: 15px;
padding: 2px 10px;
color: white;
@@ -495,7 +471,7 @@ h3 span.arrow {
height: 0;
border-left: 6px solid transparent;
border-right: 6px solid transparent;
- border-top: 6px solid #1794D1;
+ border-top: 6px solid #787DAB;
margin: 0 auto;
font-size: 0;
line-height: 0px;
@@ -504,7 +480,7 @@ h3 span.arrow {
/* home: pkgsearch box */
#pkgsearch {
padding: 1em 0.75em;
- background: #3ad;
+ background: #787DAB;
color: #fff;
border: 1px solid #08b;
}
@@ -1078,13 +1054,6 @@ ul.signoff-list {
position: relative; top: -0.9em;
}
-/* highlight current website in the navbar */
-#archnavbar.anb-home ul li#anb-home a,
-#archnavbar.anb-packages ul li#anb-packages a,
-#archnavbar.anb-download ul li#anb-download a {
- color: white !important;
-}
-
/* visualizations page */
.visualize-buttons {
margin: 0.5em 0.33em;
diff --git a/sitestatic/freedomincluded.png b/sitestatic/freedomincluded.png
new file mode 100644
index 00000000..87ce39be
--- /dev/null
+++ b/sitestatic/freedomincluded.png
Binary files differ
diff --git a/sitestatic/gnuchile.png b/sitestatic/gnuchile.png
new file mode 100644
index 00000000..b6f9bfb8
--- /dev/null
+++ b/sitestatic/gnuchile.png
Binary files differ
diff --git a/sitestatic/logos/Makefile b/sitestatic/logos/Makefile
new file mode 100644
index 00000000..1fa00733
--- /dev/null
+++ b/sitestatic/logos/Makefile
@@ -0,0 +1,15 @@
+include ../../common.mk
+
+files = \
+ apple-touch-icon-114x114.png \
+ apple-touch-icon-144x144.png \
+ apple-touch-icon-57x57.png \
+ apple-touch-icon-72x72.png \
+ icon-transparent-64x64.png
+
+all: $(files)
+clean:
+ rm -f -- $(files)
+
+$(files): %: $(branding)/%
+ cp $< $@
diff --git a/sitestatic/naltu.png b/sitestatic/naltu.png
new file mode 100644
index 00000000..0fb4624b
--- /dev/null
+++ b/sitestatic/naltu.png
Binary files differ
diff --git a/sitestatic/venenux.png b/sitestatic/venenux.png
new file mode 100644
index 00000000..9db96bba
--- /dev/null
+++ b/sitestatic/venenux.png
Binary files differ
diff --git a/templates/base.html b/templates/base.html
index 5702c8e0..dd8e7a61 100644
--- a/templates/base.html
+++ b/templates/base.html
@@ -20,10 +20,9 @@
<ul id="archnavbarlist">
<li id="anb-home"><a href="/" title="{{ BRANDING_SHORTNAME }} news, packages, projects and more">Home</a></li>
<li id="anb-packages"><a href="/packages/" title="{{ BRANDING_SHORTNAME }} Package Database">Packages</a></li>
- <li id="anb-forums"><a href="https://bbs.archlinux.org/" title="Community forums">Forums</a></li>
<li id="anb-wiki"><a href="{% wiki_url %}" title="Community documentation">Wiki</a></li>
<li id="anb-bugs"><a href="{{ BUGTRACKER_URL }}" title="Report and track bugs">Bugs</a></li>
- <li id="anb-aur"><a href="https://aur.archlinux.org/" title="Arch Linux User Repository">AUR</a></li>
+ <li id="anb-projects"><a href="{{ PROJECTS_URL }}" title="Our Code">Projects</a></li>
<li id="anb-download"><a href="{% url 'page-download' as pdl %}{{ pdl }}" title="Get {{ BRANDING_DISTRONAME }}">Download</a></li>
</ul>
</div>
@@ -39,10 +38,8 @@
<li><a href="/packages/signoffs/" title="Package signoffs">Signoffs</a></li>
<li><a href="/todo/" title="Developer todo lists">Todos</a></li>
<li><a href="{% url 'devel-clocks' %}" title="Developer world clocks">Dev Clocks</a></li>
- <li><a href="{{ MAILMAN_BASE_URL }}/mailman/private/arch-dev/"
- title="arch-dev mailing list archives">Archives</a></li>
- <li><a href="https://stats.archlinux.org/munin/"
- title="Arch server monitoring">Server Monitoring</a></li>
+ <li><a href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/dev/"
+ title="dev mailing list archives">Archives</a></li>
{% if user.is_staff %}
<li><a href="{% url 'admin:index' %}" title="Django Admin Interface">Django Admin</a></li>
{% endif %}
@@ -69,16 +66,14 @@
</div>
{% endblock %}
<div id="footer">
- <p>Copyright &copy; 2002-{% now "Y" %} <a href="mailto:jvinet@zeroflux.org"
+ <p>Copyleft 2009-{% now "Y" %} Parabola Project. All content is
+ released under the <a
+ href="http://creativecommons.org/licenses/by-sa/3.0/"
+ rel="license">cc by-sa 3.0 unported</a> license.</p>
+ <p>Website software and layout is derivative of archweb,
+ Copyright &copy; 2002-{% now "Y" %} <a href="mailto:jvinet@zeroflux.org"
title="Contact Judd Vinet">Judd Vinet</a> and <a href="mailto:aaron@archlinux.org"
title="Contact Aaron Griffin">Aaron Griffin</a>.</p>
-
- <p>The Arch Linux name and logo are recognized
- <a href="{% wiki_url 'DeveloperWiki:TrademarkPolicy' %}"
- title="Arch Linux Trademark Policy">trademarks</a>. Some rights reserved.</p>
-
- <p>The registered trademark Linux® is used pursuant to a sublicense from LMI,
- the exclusive licensee of Linus Torvalds, owner of the mark on a world-wide basis.</p>
</div>
</div>
{% block script_block %}{% endblock %}
diff --git a/templates/devel/clock.html b/templates/devel/clock.html
index 6dc7defd..6ed890c1 100644
--- a/templates/devel/clock.html
+++ b/templates/devel/clock.html
@@ -4,16 +4,16 @@
{% load flags %}
{% load tz %}
-{% block title %}{{ BRANDING_DISTRONAME }} - Developer World Clocks{% endblock %}
+{% block title %}{{ BRANDING_DISTRONAME }} - Hacker World Clocks{% endblock %}
{% block head %}<link rel="stylesheet" type="text/css" href="{% static "flags/fam.css" %}" media="screen, projection" />{% endblock %}
{% block content %}
<div id="dev-clocks-box" class="box">
- <h2>Developer World Clocks</h2>
+ <h2>Hacker World Clocks</h2>
- <p>This page helps prevent you from waking a sleeping developer. It also
- depends on developers keeping the time zone information up to date, so if
+ <p>This page helps prevent you from waking a sleeping hacker. It also
+ depends on hackers keeping the time zone information up to date, so if
you see 'UTC' listed, pester them to update their settings.</p>
<p>The "Last Action" column shows the last time this developer has done
something we know about. Considered dates for each developer include:</p>
@@ -33,7 +33,7 @@
<table id="clocks-table" class="results">
<thead>
<tr>
- <th>Developer</th>
+ <th>Hacker</th>
<th>Username</th>
<th>Alias</th>
<th>Last Action</th>
diff --git a/templates/devel/index.html b/templates/devel/index.html
index 8ed9f9ac..72f149a3 100644
--- a/templates/devel/index.html
+++ b/templates/devel/index.html
@@ -5,7 +5,7 @@
{% load package_extras %}
{% load todolists %}
-{% block title %}{{ BRANDING_DISTRONAME }} - Developer Dashboard{% endblock %}
+{% block title %}{{ BRANDING_DISTRONAME }} - Hacker Dashboard{% endblock %}
{% block content %}
<div id="dev-dashboard" class="box">
diff --git a/templates/packages/details.html.jinja b/templates/packages/details.html.jinja
index 21be80f5..b8fc9073 100644
--- a/templates/packages/details.html.jinja
+++ b/templates/packages/details.html.jinja
@@ -13,6 +13,7 @@
<li>
<a href="{{ bugs_list(pkg) }}" title="View existing bug tickets for {{ pkg.pkgname }}">Bug Reports</a> /
<a href="{{ bug_report(pkg) }}" title="Report new bug for {{ pkg.pkgname }}">Add New Bug</a>
+ / <a href="{{ flag_unfree(pkg) }}" title="Report {{ pkg.pkgname }} as unfree">Report as unfree</a>
</li>
<li><a href="{{ wiki_link(pkg) }}" title="Search wiki for {{ pkg.pkgname }}">Search Wiki</a></li>
{% if pkg.flag_date %}
@@ -28,11 +29,15 @@
<li><a href="unflag/all/" title="Unflag all matching pkgbase">Click here to unflag all split packages</a></li>
{% endif %}
{% else %}
+ {% if pkg.repo.name != "Core" and pkg.repo.name != "Extra" and pkg.repo.name != "Testing" and pkg.repo.name != "Community" and pkg.repo.name != "Community-Testing" and pkg.repo.name != "Multilib" and pkg.repo.name != "Multilib-testing" or pkg.arch.name == "mips64el" %}
<li><a href="flag/" title="Flag {{ pkg.pkgname }} as out-of-date">Flag Package Out-of-Date</a>
<a href="/packages/flaghelp/"
title="Get help on package flagging"
onclick="return !window.open('/packages/flaghelp/','FlagHelp',
'height=350,width=450,location=no,scrollbars=yes,menubars=no,toolbars=no,resizable=no');">(?)</a></li>
+ {% elif pkg.arch.name == "i686" or pkg.arch.name == "x86_64" %}
+ <li>This package comes from Arch</li>
+ {% endif %}
{% endif %}
<li><a href="download/" rel="nofollow" title="Download {{ pkg.pkgname }} from mirror">Download From Mirror</a></li>
</ul>
diff --git a/templates/packages/differences.html b/templates/packages/differences.html
index bde05a50..6220392c 100644
--- a/templates/packages/differences.html
+++ b/templates/packages/differences.html
@@ -10,6 +10,35 @@
<div class="box">
<h2>Package Differences by Architecture</h2>
<div class="filter-criteria">
+ <h3>Select architectures</h3>
+ <form id="arch_selector" method="get" action=".">
+ <fieldset>
+ <legend>Select arches</legend>
+ <div><label for="arch_a" title="Architecture A">Architecture A</label>
+ <select name="arch_a" id="arch_a">
+ {% for arch in arches %}
+ <option
+ {% if arch == arch_a %}
+ selected="selected"
+ {% endif %}
+ >{{ arch }}</option>
+ {% endfor %}
+ </select>
+ </div>
+ <div><label for="arch_b" title="Architecture B">Architecture B</label>
+ <select name="arch_b" id="arch_b">
+ {% for arch in arches %}
+ <option
+ {% if arch == arch_b %}
+ selected="selected"
+ {% endif %}
+ >{{ arch }}</option>
+ {% endfor %}
+ </select>
+ </div>
+ <div><label>&nbsp;</label><input type="submit" title="Show difference between selected architectures"></div>
+ </fieldset>
+ </form>
<h3>Filter Differences View</h3>
<form id="diff_filter" method="post" action=".">
<fieldset>
diff --git a/templates/packages/flag.html b/templates/packages/flag.html
index e66d3472..ecf2fc78 100644
--- a/templates/packages/flag.html
+++ b/templates/packages/flag.html
@@ -23,8 +23,8 @@
<p>The message box portion is meant
for short messages only. If you need more than 200 characters for your
message, then file a bug report, email the maintainer directly, or send
- an email to the <a href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/arch-general"
- title="Visit the arch-general mailing list">arch-general mailing list</a>
+ an email to the <a href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/dev"
+ title="Visit the dev mailing list">dev mailing list</a>
with your additional text.</p>
<p><strong>Note:</strong> Do <em>not</em> use this facility if the
diff --git a/templates/packages/flaghelp.html b/templates/packages/flaghelp.html
index 5f013cd7..d84dc11c 100644
--- a/templates/packages/flaghelp.html
+++ b/templates/packages/flaghelp.html
@@ -24,8 +24,8 @@
<p>The message box portion of the flag utility is meant
for short messages only. If you need more than 200 characters for your
message, then file a bug report, email the maintainer directly, or send
- an email to the <a target="_blank" href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/arch-general"
- title="Visit the arch-general mailing list">arch-general mailing list</a>
+ an email to the <a target="_blank" href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/dev"
+ title="Visit the dev mailing list">dev mailing list</a>
with your additional text.</p>
<p><strong>Note:</strong> Please do <em>not</em> use this facility if the
diff --git a/templates/packages/removed.html b/templates/packages/removed.html
index 2d730130..7f6600ee 100644
--- a/templates/packages/removed.html
+++ b/templates/packages/removed.html
@@ -18,10 +18,7 @@
{% endfor %}
</ul>
{% else %}
- <p>Unfortunately, this package cannot be found in any other repositories.
- Try using the <a href="{% url 'packages-search' %}?name={{ update.pkgname|urlencode }}">package search page</a>,
- or try <a href="https://aur.archlinux.org/packages.php?K={{ update.pkgname|urlencode }}">searching the AUR</a>
- to see if the package can be found there.</p>
+ <p>Unfortunately, this package cannot be found in any other repositories.</p>
{% endif %}
</div>
{% endblock %}
diff --git a/templates/packages/search.html b/templates/packages/search.html
index a7433934..7509864e 100644
--- a/templates/packages/search.html
+++ b/templates/packages/search.html
@@ -134,16 +134,14 @@
{% endif %}
</form>
</div>
-
<div id="pkglist-about" class="box">
<p>Can't find what you are looking for? Try searching again
- using different criteria, or try
- {% if search_form.q.data %}
- <a href="https://aur.archlinux.org/packages.php?K={{ search_form.q.data|urlencode }}">searching the AUR</a>
- {% else %}searching the <a href="https://aur.archlinux.org/">AUR</a>{% endif %}
- to see if the package can be found there.</p>
+ using different criteria.</p>
<p>You are browsing the {{ BRANDING_DISTRONAME }} package database. From here you can find
- detailed information about packages located in the official supported repositories.</p>
+ detailed information about packages located in the official supported repositories.
+ If you need the sourceball from where a package is built, you can look at our <a
+ href="https://repo.parabolagnulinux.org/sources/packages"
+ title="Sourceballed packages">sources repo</a>.</p>
</div>
{% endblock %}
diff --git a/templates/public/about.html b/templates/public/about.html
index f5751d42..b31b05ed 100644
--- a/templates/public/about.html
+++ b/templates/public/about.html
@@ -1,57 +1,62 @@
{% extends "base.html" %}
+{% load wiki %}
{% block title %}{{ BRANDING_DISTRONAME }} - About{% endblock %}
{% block content %}
<div class="box">
- <h2 class="title">About Arch Linux</h2>
-<p>
-Arch Linux is an independently developed, i686/x86-64 general purpose GNU/Linux
-distribution versatile enough to suit any role. Development focuses on
-simplicity, minimalism, and code elegance. Arch is installed as a
-minimal base system, configured by the user upon which their own ideal
-environment is assembled by installing only what is required or desired
-for their unique purposes. GUI configuration utilities are not officially
-provided, and most system configuration is performed from the shell by editing
-simple text files. Arch strives to stay bleeding edge, and typically offers
-the latest stable versions of most software.
-</p>
-<p>
-Arch Linux uses its own Pacman package manager, which couples simple binary
-packages with an easy-to-use package build system. This allows users to
-easily manage and customize packages ranging from official Arch software to the
-user's own personal packages to packages from 3rd party sources. The repository
-system also allows users to easily build and maintain their own custom build
-scripts, packages, and repositories, encouraging community growth and
-contribution.
-</p>
-<p>
-The minimal Arch base package set resides in the streamlined [core] repository.
-In addition, the official [extra], [community], and [testing] repositories
-provide several thousand high-quality, packages to meet your software demands.
-Arch also offers an [unsupported] section in the Arch Linux User Repository
-(AUR), which contains over 9,000 build scripts, for compiling installable
-packages from source using the Arch Linux makepkg application.
-</p>
-<p>
-Arch Linux uses a "rolling release" system which allows one-time installation
-and perpetual software upgrades. It is not generally necessary to reinstall
-or upgrade your Arch Linux system from one "version" to the next.
-By issuing one command, an Arch system is kept up-to-date and on the bleeding
-edge.
-</p>
-<p>
-Arch strives to keep its packages as close to the original upstream software as
-possible. Patches are applied only when necessary to ensure an application
-compiles and runs correctly with the other packages installed on an up-to-date
-Arch system.
-</p>
-<p>
-To summarize: Arch Linux is a versatile, and simple distribution designed to
-fit the needs of the competent Linux&#0174; user. It is both powerful and easy
-to manage, making it an ideal distro for servers and workstations. Take it in
-any direction you like. If you share this vision of what a GNU/Linux
-distribution should be, then you are welcomed and encouraged to use it freely,
-get involved, and contribute to the community. Welcome to Arch!
-</p>
+ <h2 class="title">Parabola Presentation</h2>
+
+ <p>In 2009 we started a project to offer the Free Software
+ community the chance of using an Arch Linux system completely
+ freed from proprietary software.</p>
+
+ <p>Today we have repositories and installable images of this wonderful
+ GNU/Linux distribution from which we have eliminated the non-free software
+ contained in its official repositories and which we have replaced with libre
+ alternatives whenever we could.</p>
+
+ <p>The first example is Linux-libre, the kernel without blobs nor nonfree
+ firmware. Followed by GNU IceCat, the libre fork of Mozilla Firefox that
+ doesn't recommend non-libre addons, and that in our case neither recommends
+ services that spy on you like the Google search engine.</p>
+
+ <h3>Why you should use Parabola</h3>
+
+ <p>Parabola equals software freedom plus all power to the users. GNU plus
+ ArchWay. With a continuosly updated system, simple to manage, simple to
+ package, you can build your own operating system in the way you want and
+ learn a lot along the way.</p>
+
+ <h3>Free Arch Linux</h3>
+
+ <p>Following the minimalist, KISS, spirit of Arch, we have managed to
+ achieve its freedom in a simple way. To free your Arch Linux installation,
+ just install our libre repositories list and update your system.</p>
+
+ <p>No reinstallation needed.</p>
+
+ <h3>Participate</h3>
+
+ <p>Boring tasks are always available. We want to start new projects. We want
+ to help people have servers of their own, with services of their own, with
+ Parabola Social. We want people to remix their own Arch Linux and share it
+ with the rest of the world.</p>
+
+ <p>We want Free Software with a social utility for a libre society.</p>
+
+ <p>But we need your help. If all of us share a little of the boring work,
+ we'll have more time to do the really fun stuff.</p>
+
+ <p>Remaining tasks:</p>
+
+ <ul>
+ <li>Audit repositories. If you find a non-libre package, or a package
+ with non-libre parts, report it as a bug.</li>
+
+ <li>Host repositories. Mirrors are not abundant.</li>
+
+ <li>Take a look at our <a href="{% wiki_url 'TODO' %}" title="TODO">TODO list</a></li>
+ </ul>
+
</div>
<br /><br />
{% endblock %}
diff --git a/templates/public/art.html b/templates/public/art.html
index 89f1f81e..80c5ac95 100644
--- a/templates/public/art.html
+++ b/templates/public/art.html
@@ -7,125 +7,51 @@
<div id="artwork" class="box">
<h2>{{ BRANDING_DISTRONAME }} Logos and Artwork</h2>
+
+ <p>You can help by creating artwork for {{ BRANDING_DISTRONAME }}.</p>
+ <p>Send your designs to dev@lists.parabolagnulinux.org and state they are CC-by-sa
+ or another free culture friendly license.</p>
+
+{% comment %}
<h3>Logos for Press Usage</h3>
- <p>The following {{BRANDING_DISTRONAME}} logos are available for press and other use, subject to
- the restrictions of our <a href="{% wiki_url 'DeveloperWiki:TrademarkPolicy' %}"
- title="{{BRANDING_DISTRONAME}} Trademark Policy">trademark policy</a>.</p>
+ <p>The following {{BRANDING_DISTRONAME}} logos are available for press and other use.</p>
<p><strong>Two-color standard version</strong><br />
+
+<!-- This is an example of how images should be added here -->
<em>Also available in print-quality
- <a href="{% static "logos/archlinux-logo-dark-1200dpi.png" %}"
+ <a href="{% static "logos/parabola-logo-dark-1200dpi.png" %}"
title="Download 1200dpi PNG format">PNG</a> and scalable
- <a href="{% static "logos/archlinux-logo-dark-scalable.svg" %}"
+ <a href="{% static "logos/parabola-logo-dark-scalable.svg" %}"
title="Download scalable SVG format">SVG</a> formats.</em></p>
- <img src="{% static "logos/archlinux-logo-dark-90dpi.png" %}"
- alt="Arch Linux PNG logo @ 90dpi" title="Arch Linux PNG logo @ 90dpi" />
+ <img src="{% static "logos/parabola-logo-dark-90dpi.png" %}"
+ alt="Parabola PNG logo @ 90dpi" title="Parabola PNG logo @ 90dpi" />
<p><strong>Two-color inverted version</strong> (for dark backgrounds)<br />
- <em>Also available in print-quality
- <a href="{% static "logos/archlinux-logo-light-1200dpi.png" %}"
- title="Download 1200dpi PNG format">PNG</a> and scalable
- <a href="{% static "logos/archlinux-logo-light-scalable.svg" %}"
- title="Download scalable SVG format">SVG</a> formats.</em></p>
- <img src="{% static "logos/archlinux-logo-light-90dpi.png" %}"
- alt="Arch Linux PNG logo @ 90dpi" title="Arch Linux PNG logo @ 90dpi" class="inverted" />
<p><strong>One-color standard version</strong><br />
- <em>Also available in print-quality
- <a href="{% static "logos/archlinux-logo-black-1200dpi.png" %}"
- title="Download 1200dpi PNG format">PNG</a> and scalable
- <a href="{% static "logos/archlinux-logo-black-scalable.svg" %}"
- title="Download scalable SVG format">SVG</a> formats.</em></p>
- <img src="{% static "logos/archlinux-logo-black-90dpi.png" %}"
- alt="Arch Linux PNG logo @ 90dpi" title="Arch Linux PNG logo @ 90dpi" />
<p><strong>One-colour inverted version</strong> (for dark backgrounds)<br />
- <em>Also available in print-quality
- <a href="{% static "logos/archlinux-logo-white-1200dpi.png" %}"
- title="Download 1200dpi PNG format">PNG</a> and scalable
- <a href="{% static "logos/archlinux-logo-white-scalable.svg" %}"
- title="Download scalable SVG format">SVG</a> formats.</em></p>
-
- <img src="{% static "logos/archlinux-logo-white-90dpi.png" %}"
- alt="Arch Linux PNG logo @ 90dpi" title="Arch Linux PNG logo @ 90dpi" class="inverted" />
<h3>Logos and Artwork for the Community</h3>
<p>Official logos and artwork are also available directly from the
- repositories. Currently, these packages are:</p>
+ repositories. These packages would be:</p>
<ul>
- <li><strong>archlinux-artwork</strong> - official logos, icons and CD labels</li>
- <li><strong>archlinux-wallpaper</strong> - a variety of desktop wallpapers
+ <li><strong>parabola-artwork</strong> - official logos, icons and CD labels</li>
+ <li><strong>parabola-wallpaper</strong> - a variety of desktop wallpapers
for standard and widescreen resolutions</li>
- <li><strong>archlinux-themes-kde</strong> - KDE themes and icons</li>
- <li><strong>archlinux-themes-kdm</strong> - KDM login themes</li>
- <li><strong>archlinux-themes-slim</strong> - SLiM login themes</li>
+ <li><strong>parabola-themes-kde</strong> - KDE themes and icons</li>
+ <li><strong>parabola-themes-kdm</strong> - KDM login themes</li>
+ <li><strong>parabola-themes-slim</strong> - SLiM login themes</li>
</ul>
-
- <p>Alternatively, you can <a href="ftp://ftp.archlinux.org/other/artwork/"
- title="Browse the FTP archives">download the source files via FTP</a>.</p>
-
- <h3>Former Logos</h3>
-
- <p>Arch has gone through a few generations of branding and what follows are
- some of our past logos. Although these images are no longer used frequently,
- they remain subject to license restrictions. Email
- <strong>trademarks@archlinux.org</strong> with any questions.</p>
-
- <h4>Original Ribbon Series</h4>
-
- <div class="imagelist">
- <img src="{% static "logos/legacy/arch-legacy-ribbon1.png" %}" alt="Arch Ribbon Logo 1"/>
- <img src="{% static "logos/legacy/arch-legacy-ribbon2.png" %}" alt="Arch Ribbon Logo 2"/>
- <img src="{% static "logos/legacy/arch-legacy-ribbon5.png" %}" alt="Arch Ribbon Logo 5"/>
- </div>
-
- <div class="imagelist">
- <img src="{% static "logos/legacy/arch-legacy-ribbon3.png" %}" alt="Arch Ribbon Logo 3"/>
- <img src="{% static "logos/legacy/arch-legacy-ribbon4.png" %}" alt="Arch Ribbon Logo 4"/>
- <img src="{% static "logos/legacy/arch-legacy-ribbon6.png" %}" alt="Arch Ribbon Logo 6"/>
- </div>
-
- <h4>"Arch Blue" Series</h4>
-
- <div class="imagelist">
- <a href="{% static "logos/legacy/arch-legacy-blue1.svg" %}" title="Arch Blue">
- <img src="{% static "logos/legacy/arch-legacy-blue1.png" %}" alt="Arch Blue"/></a>
- <a href="{% static "logos/legacy/arch-legacy-blue2.svg" %}" title="Arch Blue Vertical">
- <img src="{% static "logos/legacy/arch-legacy-blue2.png" %}" alt="Arch Blue Vertical"/></a>
- </div>
-
- <h4>"Arch Aqua" Series</h4>
-
- <div class="imagelist">
- <a href="{% static "logos/legacy/arch-legacy-aqua.svg" %}" title="Arch Aqua">
- <img src="{% static "logos/legacy/arch-legacy-aqua.png" %}" alt="Arch Aqua" /></a>
- <a href="{% static "logos/legacy/arch-legacy-aqua-blue.svg" %}" title="Arch Aqua Blue">
- <img src="{% static "logos/legacy/arch-legacy-aqua-blue.png" %}" alt="Arch Aqua Blue" /></a>
- <a href="{% static "logos/legacy/arch-legacy-aqua-white.svg" %}" title="Arch Aqua White">
- <img src="{% static "logos/legacy/arch-legacy-aqua-white.png" %}" alt="Arch Aqua White" /></a>
- </div>
-
- <h4>Release-specific Series</h4>
-
- <div class="imagelist">
- <a href="{% static "logos/legacy/arch-legacy-wombat-lg.png" %}" title="Arch Wombat">
- <img src="{% static "logos/legacy/arch-legacy-wombat.png" %}" alt="Arch Wombat" /></a>
- <a href="{% static "logos/legacy/arch-legacy-noodle-blue.svg" %}" title="Arch Noodle Blue">
- <img src="{% static "logos/legacy/arch-legacy-noodle-blue.png" %}" alt="Arch Noodle Blue" /></a>
- <a href="{% static "logos/legacy/arch-legacy-noodle-white.svg" %}" title="Arch Noodle White">
- <img src="{% static "logos/legacy/arch-legacy-noodle-white.png" %}" alt="Arch Noodle White" /></a>
- <a href="{% static "logos/legacy/arch-legacy-noodle-box.svg" %}" title="Arch Box of Noodles">
- <img src="{% static "logos/legacy/arch-legacy-noodle-box.png" %}" alt="Arch Box of Noodles" /></a>
- <a href="{% static "logos/legacy/arch-legacy-noodle-cup.svg" %}" title="Arch Cup of Noodles">
- <img src="{% static "logos/legacy/arch-legacy-noodle-cup.png" %}" alt="Arch Cup of Noodles" /></a>
- </div>
+{% endcomment %}
</div><!-- #artwork -->
{% endblock %}
diff --git a/templates/public/donate.html b/templates/public/donate.html
index 7b104e4e..f7087dc9 100644
--- a/templates/public/donate.html
+++ b/templates/public/donate.html
@@ -1,6 +1,7 @@
{% extends "base.html" %}
{% load cache %}
{% load static from staticfiles %}
+{% load wiki %}
{% block title %}{{ BRANDING_DISTRONAME }} - Donate{% endblock %}
@@ -10,63 +11,18 @@
<h2>Donate to {{ BRANDING_SHORTNAME }}</h2>
- <p>Arch Linux survives because of the tireless efforts of many people in
- the community and the core development circle. None of us are paid for
- our work, and we don't have the personal funds to sustain server costs
- ourselves.</p>
+ <h3>We don't accept any money donations</h3>
- <p>There are many ways to help support Arch Linux. If technical development,
- documentation, or support aren't your strong points, you could certainly
- help us by dropping a few bucks our way.</p>
+ <p>That's right. At the moment, Parabola isn't accepting any money
+ donations. And that's because we have nothing to do with them. We really
+ don't, at the moment. So, some voluntary work is much preferred than
+ anything, because we are a really small community of hackers.</p>
- <p>Many thanks!</p>
+ <p>If you want, we have a pretty nice <a
+ href="{% wiki_url 'TODO' %}" title="The TODO
+ list!">TODO list</a> you can check to help us by donating some of your
+ time. That will be very much appreciated by us :)</p>
- <h3>Monetary donations</h3>
-
- <p>Financial contributions are accepted via <a href="https://co.clickandpledge.com/Default.aspx?WID=47294" title="Donate via Click&amp;Pledge to Arch Linux">Click&amp;Pledge</a>.
- Arch Linux is a member project of the
- <a href="http://www.spi-inc.org/">Software in the Public Interest, Inc.</a>
- non-profit corporation. Funds are used for hosting costs, server hardware
- upgrades, and more. You are encouraged to learn more about the SPI, as well
- as <a href="http://www.spi-inc.org/donations/">how donations work</a>.</p>
-
- <a href="https://co.clickandpledge.com/Default.aspx?WID=47294">
- <img width="210" height="34" src="{% static "click_and_pledge.png" %}" alt="Donate via Click&amp;Pledge to Arch Linux" title="Donate via Click&amp;Pledge to Arch Linux"/>
- </a>
-
- <h3>Commercial sponsors and contributions</h3>
-
- <p>We'd like to thank <a href="http://www.velocitynetwork.net/?hosting_by=ArchLinux"
- title="velocity network">Velocity Network</a> for contributing space
- in a server rack, bandwidth, and electricity for our main server.</p>
-
- <a href="http://www.velocitynetwork.net/?hosting_by=ArchLinux"
- title="velocity network"><img width="252" height="58" src="{% static "vnet_button.png" %}" class="sponsor-btn-vnet"
- title="" alt="velocity network - it's about time" /></a>
-
- <p>More thanks go to <a href="http://www.airvm.com/ArchLinux"
- title="AirVM.com">AirVM.com</a> for contributing a VMWare-based Virtual Machine.</p>
-
- <a href="http://www.airvm.com/ArchLinux"
- title="AirVM.com - Your Green Technology Partner"><img width="252" height="58" src="{% static "airvm_button.png" %}"
- class="sponsor-btn-airvm" title="AirVM.com - Your Green Technology Partner" alt="AirVM.com - Your Green Technology Partner" /></a>
-
- <p>We would also like to thank Kartenzia for sponsoring a dedicated Arch Linux Server.
- Kartenzia.de is a new Start-Up based in Germany and specializes in
- eco-friendly invitations like <a href="http://www.kartenzia.de/weihnachtskarten/">Weihnachten</a>.</p>
-
- <a href="http://www.kartenzia.de/"><img width="292" height="74" src="{% static "kartenzia_button.png" %}" class="sponsor-btn-kartenzia" /></a>
-
- <h3>Past donors</h3>
-
- <div id="donor-list">
- <ul>
-{% for donor in donors %}
-<li>{{ donor.name }}</li>{% endfor %}
- </ul>
- </div>
- <div class="clear"></div>
- <p>A huge thanks to you all for your contributions!</p>
</div>
{% endcache %}
{% endblock %}
diff --git a/templates/public/download.html b/templates/public/download.html
deleted file mode 100644
index 80d636a2..00000000
--- a/templates/public/download.html
+++ /dev/null
@@ -1,114 +0,0 @@
-{% extends "base.html" %}
-{% load cache %}
-{% load static from staticfiles %}
-{% load flags %}
-{% load wiki %}
-
-{% block title %}{{ BRANDING_DISTRONAME }} - Downloads{% endblock %}
-
-{% block head %}
-<link rel="stylesheet" type="text/css" href="{% static "flags/fam.css" %}" media="screen, projection" />
-<link rel="alternate" type="application/rss+xml" title="{{BRANDING_DISTRONAME}} Releases" href="/feeds/releases/" />
-{% endblock %}
-
-{% block navbarclass %}anb-download{% endblock %}
-
-{% block content %}
-<div id="arch-downloads" class="box">
-
- <h2>{{BRANDING_DISTRONAME}} Downloads</h2>
-
- <h3>Release Info</h3>
-
- <p>The image can be burned to a CD, mounted as an ISO file,
- or be directly written to a USB stick using a utility like `dd`. It
- is intended for new installations only; an existing {{BRANDING_DISTRONAME}} system
- can always be updated with `pacman -Syu`.</p>
-
- <ul>
- {% if release.version %}<li><strong>Current Release:</strong> {{ release.version }}</li>{% endif %}
- {% if release.kernel_version %}<li><strong>Included Kernel:</strong> {{ release.kernel_version }}</li>{% endif %}
- {% if release.torrent_data %}<li><strong>ISO Size:</strong> {{ release.torrent.file_length|filesizeformat }}</li>{% endif %}
- <li><a href="{% wiki_url 'Installation_guide' %}">Installation Guide</a></li>
- <li><strong>Resources:</strong>
- <ul>
- <li><a href="https://bugs.archlinux.org/index.php?project=6"
- title="Arch Linux Bugtracker:Release Engineering">Bug Tracker</a></li>
- <li><a href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/arch-releng"
- title="Arch Linux Release Engineering mailing list">Mailing List</a></li>
- </ul>
- </li>
- </ul>
-
- {% if release.info %}
- <h3>Release Notes</h3>
-
- <div class="article-content">{{ release.info_html }}</div>
- {% endif %}
-
- <h3>Existing {{BRANDING_SHORTNAME}} Users</h3>
-
- <p>If you are an existing {{BRANDING_SHORTNAME}} user, there is no need to download a new ISO
- to update your existing system. You may be looking for
- <a href="{% url 'mirrorlist' %}">an updated mirrorlist</a> instead.</p>
-
- <h3>BitTorrent Download (recommended)</h3>
-
- <p>If you can spare the bytes, please leave the client open after your
- download is finished, so you can seed it back to others.
- <em>A web-seed capable client is recommended for fastest download speeds.</em></p>
-
- {% if release %}<ul>
- <li><a href="{{ release.magnet_uri }}"
- title="Magnet link">Magnet link for {{ release.version }}</a></li>
- <li><a href="{% url 'releng-release-torrent' release.version %}"
- title="Download torrent">Torrent for {{ release.version }}</a></li>
- </ul>{% endif %}
-
- <h3>Netboot</h3>
-
- <p>If you have a wired connection, you can boot the latest release directly over the network.</p>
- <ul>
- <li><a href="{{ releng_pxeboot_url }}"
- title="{{BRANDING_DISTRONAME}} Netboot Live System">{{BRANDING_DISTRONAME}} Linux Netboot</a></li>
- </ul>
-
- <h3>HTTP Direct Downloads</h3>
-
- <p>In addition to the BitTorrent links above, install images can also be
- downloaded via HTTP from the mirror sites listed below. Please
- ensure the download image matches the checksum from the md5sums.txt or
- sha1sums.txt file in the same directory as the image.</p>
-
- <h4>Checksums</h4>
-
- <p>File integrity checksums for the latest releases can be found below:</p>
-
- <ul>
- <li><a href="https://www.archlinux.org/{{ release.iso_url }}.sig"
- title="PGP signature">PGP signature</a></li>
- {% if release.md5_sum %}<li><strong>MD5:</strong> {{ release.md5_sum }}</li>{% endif %}
- {% if release.sha1_sum %}<li><strong>SHA1:</strong> {{ release.sha1_sum }}</li>{% endif %}
- </ul>
-
- {% cache 600 download-mirrors %}
- <div id="download-mirrors">
- {% regroup mirror_urls by country as grouped_urls %}
- {% for country in grouped_urls %}
- {% if country.grouper %}<h5>{% country_flag country.grouper %}{{ country.grouper.name }}</h5>
- {% else %}<h5>Worldwide</h5>{% endif %}
- <ul>
- {% for mirror_url in country.list %}
- <li><a href="{{ mirror_url.url }}{{ release.dir_path }}"
- title="Download from {{ mirror_url.url }}">{{ mirror_url.mirror.name }}</a></li>
- {% endfor %}
- </ul>
- {% endfor %}
- </div>
- {% endcache %}
-
- <p>If you want to become an Official {{BRANDING_DISTRONAME}} Mirror please follow the
- instructions listed <a href="{% wiki_url 'DeveloperWiki:NewMirrors' %}">here</a>.</p>
-
-</div>
-{% endblock %}
diff --git a/templates/public/feeds.html b/templates/public/feeds.html
index 9936944e..70d8eee6 100644
--- a/templates/public/feeds.html
+++ b/templates/public/feeds.html
@@ -62,9 +62,6 @@
</tbody>
</table>
- <p>A <a href="https://aur.archlinux.org/rss/" class="rss" title="AUR newest packages feed">newest packages feed</a>
- is also available from the <a href="https://aur.archlinux.org/" title="AUR Homepage">Arch User Repository (AUR)</a>.</p>
-
<h3>Release Feed</h3>
<p>Grab the <a href="/feeds/releases/" class="rss" title="{{BRANDING_DISTRONAME}} release feed">ISO release feed</a>
@@ -79,42 +76,57 @@
<thead>
<tr>
<th>Project</th>
- <th>Recently Opened Tasks</th>
- <th>Recently Edited Tasks</th>
- <th>Recently Closed Tasks</th>
+ <th>Activity</th>
+ <th>Issues</th>
+ <th>News</th>
</tr>
</thead>
<tbody>
<tr>
<td>All Projects</td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;project=0" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=edit&amp;project=0" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=clo&amp;project=0" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/news.atom" class="rss">Feed</a></td>
+ </tr><tr>
+ <td>Art4Parabola</td>
+ <td><a href="https://labs.parabola.nu/projects/art4parabola/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/art4parabola/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/art4parabola/news.atom" class="rss">Feed</a></td>
+ </tr><tr>
+ <td>Documentation</td>
+ <td><a href="https://labs.parabola.nu/projects/documentation/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/documentation/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/documentation/news.atom" class="rss">Feed</a></td>
+ </tr><tr>
+ <td>Installation media (i686 and x86_64)</td>
+ <td><a href="https://labs.parabola.nu/projects/isos/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/isos/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/isos/news.atom" class="rss">Feed</a></td>
</tr><tr>
- <td>Arch Linux</td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;project=1" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=edit&amp;project=1" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=clo&amp;project=1" class="rss">Feed</a></td>
+ <td>Libretools</td>
+ <td><a href="https://labs.parabola.nu/projects/libretools/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/libretools/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/libretools/news.atom" class="rss">Feed</a></td>
</tr><tr>
- <td>Release Engineering</td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;project=6" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=edit&amp;project=6" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=clo&amp;project=6" class="rss">Feed</a></td>
+ <td>Packages (i686 and x86_64)</td>
+ <td><a href="https://labs.parabola.nu/projects/issue-tracker/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/issue-tracker/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/issue-tracker/news.atom" class="rss">Feed</a></td>
</tr><tr>
- <td>Pacman Development</td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;project=3" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=edit&amp;project=3" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=clo&amp;project=3" class="rss">Feed</a></td>
+ <td>Ports</td>
+ <td><a href="https://labs.parabola.nu/projects/ports/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/ports/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/ports/news.atom" class="rss">Feed</a></td>
</tr><tr>
- <td>Community Packages</td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;project=5" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=edit&amp;project=5" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=clo&amp;project=5" class="rss">Feed</a></td>
+ <td>Port: Loongson 2F (mips64el)</td>
+ <td><a href="https://labs.parabola.nu/projects/mips64el/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/mips64el/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/mips64el/news.atom" class="rss">Feed</a></td>
</tr><tr>
- <td>AUR</td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;project=2" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=edit&amp;project=2" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=clo&amp;project=2" class="rss">Feed</a></td>
+ <td>Servers</td>
+ <td><a href="https://labs.parabola.nu/projects/servers/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/servers/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/servers/news.atom" class="rss">Feed</a></td>
</tr>
</tbody>
</table>
diff --git a/templates/public/https.html b/templates/public/https.html
new file mode 100644
index 00000000..df3e2c73
--- /dev/null
+++ b/templates/public/https.html
@@ -0,0 +1,49 @@
+{% extends "base.html" %}
+{% load wiki %}
+{% block title %}{{ BRANDING_DISTRONAME }} - HTTPS Only site{% endblock %}
+{% block content %}
+<div class="box">
+ <h2 class="title">This is the unsecure version of the website</h2>
+
+ <p>Hi! This is not the main site. You're seeing this message because you
+ entered our website without using a secure connection. We like privacy for
+ all so we've decided to serve our website only through secure channels. This
+ is the <em>only</em> page on the whole site that can be accessed without a
+ secure connection, all other pages will redirect to the secure version.</p>
+
+ <h2><a href="https://parabolagnulinux.org">Enter the secure site</a></h2>
+
+ <h3>But my browser says the secure site is untrusted</h3>
+
+ <p>This website's certificate issued by
+ <a href="http://cacert.org">CAcert</a>. Some web browsers or operating
+ systems still don't provide CAcert's root certificate, so if you find a huge
+ error message telling you're about to do something bad, come back here and
+ keep reading.</p>
+
+ <h4>Installing CAcert's root certificate</h4>
+
+ <p>You should ask your web browser or operating system to
+ <a href="http://wiki.cacert.org/InclusionStatus">include</a> CAcert's root
+ certificates.</p>
+
+ <p>You can install CAcert's root certificates yourself by
+ <a href="http://www.cacert.org/index.php?id=3">downloading</a> them and
+ following <a href="http://wiki.cacert.org/BrowserClients">these
+ instructions</a> on how to install them in your browser.</p>
+
+ <h4>But installing the certificate sounds hard/complicated/boring</h4>
+
+ <p>You could just click "Ignore", or "Add Exception", or however your
+ browser words it. But then, you wouldn't know that the site is actually
+ coming from us; there could be someone in the middle tricking you, or
+ spying on you and looking at which webpages you visit.</p>
+
+ <h2>I just want to get the installer ISOs</h2>
+
+ <p>You can proceed to our
+ <a href="{% wiki_url 'get' %}">ISOs download page</a> on
+ <a href="{% wiki_url %}">our wiki</a>.</p>
+
+</div>
+{% endblock %}
diff --git a/templates/public/index.html b/templates/public/index.html
index a6bd1fb1..6ef6b4bf 100644
--- a/templates/public/index.html
+++ b/templates/public/index.html
@@ -11,26 +11,27 @@
{% block content_left %}
{% cache 62 main-page-left secure %}
<div id="intro" class="box">
- <h2>A simple, lightweight distribution</h2>
-
- <p>You've reached the website for <strong>{{BRANDING_DISTRONAME}}</strong>, a
- lightweight and flexible Linux® distribution that tries to Keep It
- Simple.</p>
-
- <p>Currently we have official packages optimized for the i686 and
- x86-64 architectures. We complement our official package sets with a
- <a href="https://aur.archlinux.org/" title="Arch User Repository (AUR)">
- community-operated package repository</a> that grows in size and
- quality each and every day.</p>
-
- <p>Our strong community is diverse and helpful, and we pride ourselves
- on the range of skillsets and uses for Arch that stem from it. Please
- check out our <a href="https://bbs.archlinux.org/" title="Arch Forums">forums</a>
- and <a href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/"
- title="{{ BRANDING_SHORTNAME }} Mailing Lists">mailing lists</a>
- to get your feet wet. Also glance through our <a href="{% wiki_url %}"
- title="{{BRANDING_WIKINAME}}">wiki</a>
- if you want to learn more about {{BRANDING_SHORTNAME}}.</p>
+ <h2>A fully free, simple, and lightweight operating system</h2>
+
+ <p>You've reached the website of the Parabola&nbsp;GNU/Linux-libre operating
+ system. The Parabola project is a community driven effort to provide a
+ fully free (as in
+ <a href="https://www.gnu.org/philosophy/free-sw">freedom</a>) operating
+ system that is simple and lightweight.</p>
+
+ <p>Derived from Arch Linux, Parabola GNU/Linux-libre provides packages from
+ Arch that meet the
+ <a href="http://www.gnu.org/distros/free-system-distribution-guidelines.html">Free
+ System Distribution Guidelines (FSDG)</a> and replacements for the packages
+ that don't meet this requirement. Packages are provided for the i686,
+ x86-64, and mips64el architectures.</p>
+
+ <p>Our community is friendly and helpful. Please hop on
+ <a href="irc://chat.freenode.net#parabola">IRC channel</a> and check out our
+ <a href="https://lists.parabolagnulinux.org/mailman/listinfo/">mailing
+ lists</a> to get your feet wet. Also glance through our
+ <a href="https://wiki.parabolagnulinux.org/">wiki</a> if you want to learn
+ more about Parabola.</p>
<p class="readmore"><a href="{% url 'page-about' %}"
title="Learn more about {{ BRANDING_DISTRONAME }}">Learn more...</a></p>
@@ -117,6 +118,8 @@
title="Installation guide">Installation Guide</a></li>
<li><a href="{% wiki_url "Beginners'_guide" %}"
title="A good place to start for beginners">Beginners' Guide</a></li>
+ <li><a href="{% wiki_url 'Migration' %}"
+ title="Free your Arch installation">Migration from Arch Linux</a></li>
</ul>
<h4>Community</h4>
@@ -126,10 +129,8 @@
title="Community and developer mailing lists">Mailing Lists</a></li>
<li><a href="{% wiki_url 'IRC_channels' %}"
title="Official and regional IRC communities">IRC Channels</a></li>
- <li><a href="https://planet.archlinux.org/"
- title="Arch in the blogosphere">Planet Arch</a></li>
- <li><a href="{% wiki_url 'International_communities' %}"
- title="{{DISTRO_SHORTNAME}} communities in your native language">International Communities</a></li>
+ <li><a href="https://identi.ca/group/parabola"
+ title="Parabola at identi.ca">Identi.ca group</a></li>
</ul>
<h4>Support</h4>
@@ -137,12 +138,6 @@
<ul>
<li><a href="{% url 'page-donate' %}"
title="Help support {{ BRANDING_DISTRONAME }}">Donate</a></li>
- <li><a href="http://schwag.archlinux.ca/"
- title="USB keys, jewellery, case badges">Arch Schwag</a></li>
- <li><a href="http://www.zazzle.com/archlinux*"
- title="T-shirts, mugs, mouse pads, hoodies, posters, skateboards, shoes, etc.">Products via Zazzle</a></li>
- <li><a href="http://www.freewear.org/?page=list_items&amp;org=Archlinux"
- title="T-shirts">T-shirts via Freewear</a></li>
</ul>
<h4>Tools</h4>
@@ -163,14 +158,16 @@
<ul>
<li><a href="{{ PROJECTS_URL }}"
title="Official {{BRANDING_SHORTNAME}} projects (git)">Projects in Git</a></li>
+{% comment %}
<li><a href="{% url 'page-svn' %}"
title="View SVN entries for packages">SVN Repositories</a></li>
<li><a href="{% wiki_url 'DeveloperWiki' %}"
title="Developer Wiki articles">Developer Wiki</a></li>
+{% endcomment %}
<li><a href="/groups/"
title="View the available package groups">Package Groups</a></li>
<li><a href="/todo/"
- title="Developer Todo Lists">Todo Lists</a></li>
+ title="Hacker Todo Lists">Todo Lists</a></li>
<li><a href="{% url 'releng-release-list' %}"
title="Release Engineering ISO listing">ISO Release List</a></li>
<li><a href="{% url 'visualize-index' %}"
@@ -182,30 +179,44 @@
<ul>
<li><a href="{% url 'page-keys' %}"
title="Package/Database signing master keys">Signing Master Keys</a></li>
- <li><a href="{% wiki_url 'Arch_Linux_press_coverage %}"
+ <li><a href="{% wiki_url 'Media' %}"
title="{{ BRANDING_DISTRONAME }} in the media">Press Coverage</a></li>
<li><a href="{% url 'page-art' %}" title="{{ BRANDING_SHORTNAME }} logos and other artwork for promotional use">Logos &amp; Artwork</a></li>
<li><a href="{% url 'news-list' %}" title="News Archives">News Archives</a></li>
<li><a href="/feeds/" title="Various RSS Feeds">RSS Feeds</a></li>
- <li><a href="{% url 'page-devs' %}" title="Active developers">Developer Profiles</a></li>
- <li><a href="{% url 'page-tus' %}" title="Active Trusted Users (TUs)">Trusted User Profiles</a></li>
- <li><a href="{% url 'page-fellows' %}" title="Retired Developers">Fellows Profiles</a></li>
+ <li><a href="{% url 'page-devs' %}" title="Active hackers">Hackers Profiles</a></li>
+ <li><a href="{% url 'page-fellows' %}" title="Retired hackers">Fellows Profiles</a></li>
</ul>
</div>
+{% comment %}
<div id="home-donate-button" class="widget">
- <a href="https://co.clickandpledge.com/Default.aspx?WID=47294">
- <img width="210" height="34" src="{% static "click_and_pledge.png" %}" alt="Donate via Click&amp;Pledge to Arch Linux" title="Donate via Click&amp;Pledge to Arch Linux"/>
- </a>
+donate button would go here
</div>
+{% endcomment %}
<div id="arch-sponsors" class="widget">
- <a href="http://www.velocitynetwork.net/?hosting_by=ArchLinux" title="Velocity Network">
- <img width="252" height="58" src="{% static "vnet_button.png" %}" alt="Velocity Network - It's about time" />
+ <a href="http://gnuchile.cl">
+ <img src="{% static "gnuchile.png" %}"
+ alt="GNU Chile - Donates the .org domain"
+ title="GNU Chile - Donates the .org domain" />
</a>
- <a href="http://www.airvm.com/ArchLinux" title="AirVM.com - Your Green Technology Partner">
- <img width="252" height="58" src="{% static "airvm_button.png" %}" alt="AirVM.com - Your Green Technology Partner" />
+
+ <img src="{% static "venenux.png" %}"
+ alt="Venenux GNU/Linux - Donates the repo, wiki and lists hosting"
+ title="Venenux GNU/Linux - Donates the repo, wiki and lists hosting" />
+
+ <a href="http://naltu.com">
+ <img src="{% static "naltu.png" %}"
+ alt="Naltú - Donates the website, bugs, projects and ABSLibre hosting"
+ title="Naltú - Donates the website, bugs, projects and ABSLibre hosting" />
+ </a>
+
+ <a href="http://freedomincluded.com">
+ <img src="{% static "freedomincluded.png" %}"
+ alt="Freedom Included - Donated Lemote Yeeloongs to port Parabola to the MIPS architecture"
+ title="Freedom Included - Donated Lemote Yeeloongs to port Parabola to the MIPS architecture" />
</a>
</div>
{% endcache %}
diff --git a/templates/public/svn.html b/templates/public/svn.html
deleted file mode 100644
index 01c2ef80..00000000
--- a/templates/public/svn.html
+++ /dev/null
@@ -1,41 +0,0 @@
-{% extends "base.html" %}
-{% block title %}{{ BRANDING_DISTRONAME }} - SVN{% endblock %}
-{% block content %}
-<div class="box">
- <h2 class="title">SVN Repositories</h2>
- <p>
- The PKGBUILD files can be fetched via the ABS utility. To learn more
- about ABS, see <a href="{% wiki_url 'ABS' %}">the ABS wiki page</a>.
- </p>
- <p>The SVN repositories have been cloned into git repositories and can be
- viewed via the cgit interface.
- <a href="{{ PROJECTS_URL }}/svntogit/packages.git/">All
- packages</a> are available here except for
- <a href="{{ PROJECTS_URL }}/svntogit/community.git/">community
- and multilib</a> which are available in a different repository.</p>
- <p>
- You can also get individual PKGBUILDs directly from SVN. This can be
- especially useful if you need to compile an older version of a package.
- <strong>DO NOT CHECK OUT THE ENTIRE SVN REPO</strong>. Your address may be
- blocked. Use the following commands to check out a specific package:
- </p>
-
- <pre>svn checkout --depth=empty svn://svn.archlinux.org/packages
-cd packages
-svn update &lt;your-package-name&gt;</pre>
-
- For the community and multilib repositories, use the following commands
- instead:
- <pre>svn checkout --depth=empty svn://svn.archlinux.org/community
-cd community
-svn update &lt;your-package-name&gt;</pre>
-
- <p>
- Visit <a href="{% wiki_url 'Getting_PKGBUILDS_From_SVN' %}">the wiki</a>
- for more tips on checking out and updating svn PKGBUILDs.
- </p>
-
-</div>
-<br /><br />
-{% endblock %}
-
diff --git a/urls.py b/urls.py
index e7f2b24c..04f5ecd2 100644
--- a/urls.py
+++ b/urls.py
@@ -25,12 +25,11 @@ urlpatterns += patterns('public.views',
(r'^$', 'index', {}, 'index'),
(r'^about/$', TemplateView.as_view(template_name='public/about.html'),
{}, 'page-about'),
+ (r'^https/$', TemplateView.as_view(template_name='public/https.html'),
+ {}, 'page-https'),
(r'^art/$', TemplateView.as_view(template_name='public/art.html'),
{}, 'page-art'),
- (r'^svn/$', TemplateView.as_view(template_name='public/svn.html'),
- {}, 'page-svn'),
- (r'^developers/$', 'userlist', { 'user_type':'devs' }, 'page-devs'),
- (r'^trustedusers/$', 'userlist', { 'user_type':'tus' }, 'page-tus'),
+ (r'^hackers/$', 'userlist', { 'user_type':'hackers' }, 'page-devs'),
(r'^fellows/$', 'userlist', { 'user_type':'fellows' }, 'page-fellows'),
(r'^donate/$', 'donate', {}, 'page-donate'),
(r'^download/$', 'download', {}, 'page-download'),
@@ -72,11 +71,6 @@ urlpatterns += patterns('',
{}, 'opensearch-packages-suggest'),
)
-# Retro home page views
-urlpatterns += patterns('retro.views',
- (r'^retro/(?P<year>[0-9]{4})/$', 'retro_homepage', {}, 'retro-homepage'),
-)
-
# Sitemaps
urlpatterns += patterns('',
(r'^sitemap.xml$',
@@ -110,11 +104,14 @@ legacy_urls = (
('^todolists/$', '/todo/'),
('^docs/en/guide/install/arch-install-guide.html',
- 'https://wiki.archlinux.org/index.php/Installation_guide'),
+ 'https://wiki.parabolagnulinux.org/Installation_guide'),
('^docs/en/',
- 'https://wiki.archlinux.org/'),
+ 'https://wiki.parabolagnulinux.org/'),
('^docs/',
- 'https://wiki.archlinux.org/'),
+ 'https://wiki.parabolagnulinux.org/'),
+
+ ('^developers/$', '/hackers/'),
+ ('^trustedusers/$', '/hackers/'),
)
urlpatterns += [url(old_url, RedirectView.as_view(url=new_url))
diff --git a/settings.py b/settings.py
index c3ffcdce..dc93eb1e 100644
--- a/settings.py
+++ b/settings.py
@@ -1,5 +1,5 @@
import os
# Django settings for archweb project.
## Set the debug values
DEBUG = False
@@ -13,7 +13,7 @@ ADMINS = ()
MANAGERS = ADMINS
# Package out-of-date emails for orphans
-NOTIFICATIONS = ['arch-notifications@archlinux.org']
+NOTIFICATIONS = ['dev@lists.parabolagnulinux.org']
# Full path to the data directory
DEPLOY_PATH = os.path.dirname(os.path.realpath(__file__))
@@ -161,42 +161,43 @@ LOGGING = {
PGP_SERVER = 'pgp.mit.edu:11371'
# URL to fetch a current list of available ISOs
-ISO_LIST_URL = 'https://releng.archlinux.org/isos/'
+ISO_LIST_URL = 'https://repo.parabolagnulinux.org/isos/'
# URL to the PXE netboot instructions
-PXEBOOT_URL = 'https://releng.archlinux.org/pxeboot/'
+PXEBOOT_URL = 'http://repo.parabolagnulinux.org/pxeboot/'
# URL for SVN access for fetching commit messages (note absence of packages or
# community bit on the end, repo.svn_root is appended)
-SVN_BASE_URL = 'svn://svn.archlinux.org/'
+#SVN_BASE_URL = 'svn://svn.archlinux.org/'
# URL for linking to mailing lists
-MAILMAN_BASE_URL = 'https://mailman.archlinux.org/'
+MAILMAN_BASE_URL = 'https://lists.parabolagnulinux.org/'
# URL for linking to the bugtracker
-BUGTRACKER_URL = 'https://bugs.archlinux.org/'
+BUGTRACKER_URL = 'https://labs.parabola.nu/'
# URL for linking to the release engineering/iso project on the bugtracker
-BUGTRACKER_RELENG_URL = 'https://bugs.archlinux.org/index.php?project=6'
+BUGTRACKER_RELENG_URL = 'https://labs.parabola.nu/projects/isos'
# URL for linking to projects in git
-PROJECTS_URL = 'https://projects.archlinux.org'
+PROJECTS_URL = 'https://projects.parabolagnulinux.org'
# Trackers used for ISO download magnet links
TORRENT_TRACKERS = (
- 'udp://tracker.archlinux.org:6969',
- 'http://tracker.archlinux.org:6969/announce',
+ 'udp://tracker.publicbt.com:80',
+ 'udp://tracker.openbittorrent.com:80',
+ 'udp://tracker.istole.it:80',
)
-DOMAIN_RE = r'^(.+\.)?archlinux.org$'
+DOMAIN_RE = r'^(.+\.)?parabolagnulinux.org$'
-BRANDING_APPNAME = 'archweb'
-BRANDING_DISTRONAME = 'Arch Linux'
-BRANDING_SHORTNAME = 'Arch'
-BRANDING_SLUG = 'archlinux'
-BRANDING_WIKINAME = 'ArchWiki'
-BRANDING_EMAIL = 'Arch Website Notification <nobody@archlinux.org>'
-BRANDING_OSEARCH_TAGS = 'linux archlinux package software'
+BRANDING_APPNAME = 'parabolaweb'
+BRANDING_DISTRONAME = 'Parabola GNU/Linux-libre'
+BRANDING_SHORTNAME = 'Parabola'
+BRANDING_SLUG = 'parabola'
+BRANDING_WIKINAME = 'ParabolaWiki'
+BRANDING_EMAIL = 'Parabola Website Notification <nobody@parabolagnulinux.org>'
+BRANDING_OSEARCH_TAGS = 'gnu linuxlibre parabola package software'
## Import local settings
from local_settings import *
@@ -1,5 +1,5 @@
import os
-# Django settings for archweb project.
+# Django settings for parabolaweb project.
## Set the debug values
DEBUG = False